Usage
dev_bern(x, prob = 0.5, res = FALSE)
Arguments
- x
A vector of 0s and 1s.
- prob
A numeric vector of values between 0 and 1 of the probability of
success.
- res
A flag specifying whether to return the deviance residual as
opposed to the deviance.
Value
An numeric vector of the corresponding deviances or deviance residuals.
See also
Other dev_dist:
dev_beta_binom(),
dev_binom(),
dev_gamma(),
dev_gamma_pois(),
dev_lnorm(),
dev_neg_binom(),
dev_norm(),
dev_pois(),
dev_pois_zi(),
dev_skewlnorm(),
dev_skewnorm(),
dev_student()
Examples
dev_bern(c(TRUE, FALSE), 0.7)
#> [1] 0.7133499 2.4079456