Negative Binomial Deviances
Arguments
- x
A non-negative whole numeric vector of values.
- lambda
A non-negative numeric vector of means.
- theta
A non-negative numeric vector of the dispersion for the mixture models (student, gamma-Poisson and beta-binomial).
- res
A flag specifying whether to return the deviance residual as opposed to the deviance.
Examples
dev_neg_binom(c(1, 2, 5), 2, 3)
#> [1] 0.1060144 0.0000000 0.3450025