Skip to contents

Skew-Lognormal Log-Likelihood

Usage

log_lik_skewlnorm(
  x,
  meanlog = 0,
  sdlog = 1,
  shape = 0,
  tlower = 0,
  tupper = Inf
)

Arguments

x

A numeric vector of values.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

tlower

A numeric vector of the lower truncation point.

tupper

A numeric vector of the upper truncation point.

Value

An numeric vector of the corresponding log-likelihoods.

Examples

log_lik_skewlnorm(1:5)
#> [1] -0.9189385 -1.8523122 -2.6210253 -3.2661389 -3.8235216
log_lik_skewlnorm(1:5, shape = -2)
#> [1]  -0.9189385  -3.6501479  -6.1964185  -8.4580739 -10.4790080
log_lik_skewlnorm(1:5, shape = 2)
#> [1] -0.9189385 -1.2456259 -1.9419793 -2.5757762 -3.1310181