| prob_beta_binom | R Documentation |
This parameterization of the beta-binomial distribution uses an expected
probability parameter, prob, and a dispersion parameter, theta. The
parameters of the underlying beta mixture are alpha = (2 * prob) / theta
and beta = (2 * (1 - prob)) / theta. This parameterization of theta is
unconventional, but has useful properties when modelling. When theta = 0,
the beta-binomial reverts to the binomial distribution. When theta = 1 and
prob = 0.5, the parameters of the beta distribution become alpha = 1 and
beta = 1, which correspond to a uniform distribution for the beta-binomial
probability parameter.
prob_beta_binom(x, size = 1, prob = 0.5, theta = 0)
x |
A numeric vector of quantiles. |
size |
A non-negative whole numeric vector of the number of trials. |
prob |
A numeric vector of values between 0 and 1 of the probability of success. |
theta |
A non-negative numeric vector of the dispersion for the mixture models (student, gamma-Poisson and beta-binomial). |
An numeric vector of the corresponding probabilities.
Other prob_dist:
prob_bern(),
prob_beta(),
prob_binom(),
prob_exp(),
prob_gamma(),
prob_gamma_pois(),
prob_gamma_pois_zi(),
prob_lnorm(),
prob_neg_binom(),
prob_norm(),
prob_pois(),
prob_pois_zi(),
prob_skewlnorm(),
prob_skewnorm(),
prob_student(),
prob_unif()
prob_beta_binom(c(0, 1, 2), 3, 0.5, 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.