Skip to contents

Log-Normal Cumulative Distribution Function

Usage

prob_lnorm(x, meanlog = 0, sdlog = 1)

Arguments

x

A numeric vector of quantiles.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

Value

An numeric vector of the corresponding probabilities.

Examples

prob_lnorm(10, 0, 2)
#> [1] 0.875194