Skip to contents

Skew-Lognormal Cumulative Distribution Function

Usage

prob_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0)

Arguments

x

A numeric vector of quantiles.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

Value

An numeric vector of the corresponding probabilities.

Examples

prob_skewlnorm(1:5)
#> [1] 0.5000000 0.7558914 0.8640314 0.9171715 0.9462397
prob_skewlnorm(1:5, shape = -2)
#> [1] 0.8524164 0.9899035 0.9991047 0.9998950 0.9999845
prob_skewlnorm(1:5, shape = 2)
#> [1] 0.1475836 0.5218793 0.7289581 0.8344480 0.8924949