Skip to contents

Log-Normal Quantile Function

Usage

quant_lnorm(x, meanlog = 0, sdlog = 1)

Arguments

x

A numeric vector of probabilities.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

Value

An numeric vector of the corresponding quantiles.

Examples

quant_lnorm(c(0.1, 0.4, 0.6), 0, 2)
#> [1] 0.07706523 0.60248398 1.65979518