Skip to contents

Skew-Lognormal Quantile Function

Usage

quant_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0)

Arguments

x

A numeric vector of probabilities.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

Value

An numeric vector of the corresponding quantiles.

Examples

quant_skewlnorm(c(0.1, 0.4, 0.6))
#> [1] 0.2776062 0.7761984 1.2883304
quant_skewlnorm(c(0.1, 0.4, 0.6), shape = -2)
#> [1] 0.1930513 0.4346470 0.6150948
quant_skewlnorm(c(0.1, 0.4, 0.6), shape = 2)
#> [1] 0.8747552 1.6257658 2.3007178