Skip to contents

Skew Normal Random Samples

Usage

ran_skewnorm(n = 1, location = 0, scale = 1, shape = 0, ..., mean, sd)

Arguments

n

A non-negative whole number of the number of random samples to generate.

location

A numeric vector of the location parameter.

scale

A non-negative numeric vector of the scale parameter.

shape

A numeric vector of shape. Negative values result in leftward skew, while positive values result in rightward skew.

...

Unused.

mean

[Deprecated] A numeric vector of the location parameter. Described as "a numeric vector of the means" prior to to v. 0.10.1. Will be removed in a future version.

sd

[Deprecated] A non-negative numeric vector of the scale parameter. Described as "a non-negative numeric vector of the standard deviations" prior to v. 0.10.1. Will be removed in a future version.

Value

A numeric vector of the random samples.

Examples

ran_skewnorm(10, shape = -1)
#>  [1] -1.4598895 -1.7300920 -0.3785464 -0.6900374 -0.9216302 -1.4594648
#>  [7] -0.9637518 -0.9933685 -0.7869584 -1.3534472
ran_skewnorm(10, shape = 0)
#>  [1] -0.3432754 -0.4327656  0.1801635  1.7244790 -0.6515033 -0.1581936
#>  [7] -1.4571486 -0.9542045  1.1945719 -0.9032592
ran_skewnorm(10, shape = 1)
#>  [1]  1.05591563 -0.57251003  0.07059691  0.13657298  0.97029838  1.84298062
#>  [7] -0.38607216  1.73498890  0.92340047  0.71429037