Skip to contents

Student's t Random Samples

Usage

ran_student(n = 1, mean = 0, sd = 1, theta = 0)

Arguments

n

A non-negative whole number of the number of random samples to generate.

mean

A numeric vector of the means.

sd

A non-negative numeric vector of the standard deviations.

theta

A non-negative numeric vector of the dispersion for the mixture models (student, gamma-Poisson and beta-binomial).

Value

A numeric vector of the random samples.

Examples

ran_student(10, theta = 1 / 2)
#>  [1]  1.98320246  1.91901978  0.70890025 -6.26206222  0.21736990 -0.77007981
#>  [7] -0.13790352 -0.50802089  0.08497869  0.49035862