Usage
res_lnorm(x, meanlog = 0, sdlog = 1, type = "dev", simulate = FALSE)
Arguments
- x
A numeric vector of values.
- meanlog
A numeric vector of the means on the log scale.
- sdlog
A non-negative numeric vector of the standard deviations on the
log scale.
- type
A string of the residual type. 'raw' for raw residuals 'dev' for
deviance residuals and 'data' for the data.
- simulate
A flag specifying whether to simulate residuals.
Value
An numeric vector of the corresponding residuals.
See also
Other res_dist:
res_bern(),
res_beta_binom(),
res_binom(),
res_gamma(),
res_gamma_pois(),
res_gamma_pois_zi(),
res_neg_binom(),
res_norm(),
res_pois(),
res_pois_zi(),
res_skewlnorm(),
res_skewnorm(),
res_student()
Examples
res_lnorm(10)
#> [1] 2.302585