Skip to contents

Skew-Lognormal Residuals

Usage

res_skewlnorm(
  x,
  meanlog = 0,
  sdlog = 1,
  shape = 0,
  type = "dev",
  simulate = FALSE
)

Arguments

x

A numeric vector of values.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

type

A string of the residual type. 'raw' for raw residuals 'dev' for deviance residuals and 'data' for the data.

simulate

A flag specifying whether to simulate residuals.

Value

An numeric vector of the corresponding residuals.

Examples

res_skewlnorm(exp(-2:2))
#> [1] -2 -1  0  1  2