Expands (sd_mult > 1) or reduces (sd_mult < 1) the standard deviation
of the Beta distribution. The Beta distribution has a maximum variance of
mean(x) * (1 - mean(x), where mean(x) = alpha / (alpha + beta). If the
inputs produce a desired variance that is greater than the maximum possible
variance, or provides alpha and/or beta parameters that are < 1 and thus
push more probability weight towards extreme probability values, this
function returns alpha = 1 and beta = 1 (the uniform distribution).
Usage
sens_beta(alpha, beta, sd_mult = 2)
Arguments
- alpha
The first shape parameter of the beta distribution.
- beta
The second shape parameter of the beta distribution.
- sd_mult
A non-negative multiplier on the standard deviation of the
distribution.
Value
A named list of the adjusted distribution's parameters.
See also
Other sens_dist:
sens_exp(),
sens_gamma(),
sens_gamma_pois(),
sens_gamma_pois_zi(),
sens_lnorm(),
sens_neg_binom(),
sens_norm(),
sens_pois(),
sens_skewlnorm(),
sens_skewnorm(),
sens_student()
Examples
sens_beta(10, 10, 2)
#> $alpha
#> [1] 2.125
#>
#> $beta
#> [1] 2.125
#>
sens_beta(10, 10, 0.8)
#> $alpha
#> [1] 15.90625
#>
#> $beta
#> [1] 15.90625
#>