Expands (sd_mult > 1) or reduces (sd_mult < 1) the standard deviation
of the Log-Normal distribution. With high values of sdlog (i.e., > 9),
and sd_mult > 1, the mean of the adjusted distribution can be expected to
have a mean value that is very different from the original mean, however,
the proportional difference in these values should not be very different.
Usage
sens_lnorm(meanlog, sdlog, sd_mult = 2)
Arguments
- meanlog
A numeric vector of the means on the log scale.
- sdlog
A non-negative numeric vector of the standard deviations on the
log scale.
- sd_mult
A non-negative multiplier on the standard deviation of the
distribution.
Value
A named list of the adjusted distribution's parameters.
See also
Other sens_dist:
sens_beta(),
sens_exp(),
sens_gamma(),
sens_gamma_pois(),
sens_gamma_pois_zi(),
sens_neg_binom(),
sens_norm(),
sens_pois(),
sens_skewlnorm(),
sens_skewnorm(),
sens_student()
Examples
sens_lnorm(0, 1, 2)
#> $meanlog
#> [1] -0.5317277
#>
#> $sdlog
#> [1] 1.436473
#>
sens_lnorm(0, 1, 0.8)
#> $meanlog
#> [1] 0.1291027
#>
#> $sdlog
#> [1] 0.861275
#>