Expands (sd_mult > 1) the standard deviation of the Negative Binomial
distribution. This function does not currently have the option to reduce the
standard deviation.
Usage
sens_neg_binom(lambda, theta, sd_mult = 2)
Arguments
- lambda
A non-negative numeric vector of means.
- theta
A non-negative numeric vector of the dispersion for the mixture
models (student, gamma-Poisson and beta-binomial).
- sd_mult
A non-negative multiplier on the standard deviation of the
distribution.
Value
A named list of the adjusted distribution's parameters.
See also
Other sens_dist:
sens_beta(),
sens_exp(),
sens_gamma(),
sens_gamma_pois(),
sens_gamma_pois_zi(),
sens_lnorm(),
sens_norm(),
sens_pois(),
sens_skewlnorm(),
sens_skewnorm(),
sens_student()
Examples
sens_neg_binom(10, 0.1, 2)
#> $lambda
#> [1] 10
#>
#> $theta
#> [1] 0.7
#>