Skip to contents

Expands (sd_mult > 1) or reduces (sd_mult < 1) the standard deviation of the Skew-Lognormal distribution while preserving its mean and shape. The adjustment is made on the natural scale (i.e. for x, not for log(x)), mirroring sens_lnorm(), to which it reduces when shape = 0.

Usage

sens_skewlnorm(meanlog, sdlog, shape, sd_mult = 2)

Arguments

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A non-negative numeric vector of shape.

sd_mult

A non-negative multiplier on the standard deviation of the distribution.

Value

A named list of the adjusted distribution's parameters.

Examples

sens_skewlnorm(0, 1, 2, 2)
#> $meanlog
#> [1] -0.6406637
#> 
#> $sdlog
#> [1] 1.441698
#> 
#> $shape
#> [1] 2
#> 
sens_skewlnorm(0, 1, 2, 0.8)
#> $meanlog
#> [1] 0.1720714
#> 
#> $sdlog
#> [1] 0.8620703
#> 
#> $shape
#> [1] 2
#>