dev_skewlnorm: Skew-Lognormal Deviances

View source: R/dev.R

dev_skewlnormR Documentation

Skew-Lognormal Deviances

Description

Skew-Lognormal Deviances

Usage

dev_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0, res = FALSE)

Arguments

x

A numeric vector of values.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

res

A flag specifying whether to return the deviance residual as opposed to the deviance.

Value

An numeric vector of the corresponding deviances or deviance residuals.

See Also

Other dev_dist: dev_bern(), dev_beta_binom(), dev_binom(), dev_gamma(), dev_gamma_pois(), dev_lnorm(), dev_neg_binom(), dev_norm(), dev_pois(), dev_pois_zi(), dev_skewnorm(), dev_student()

Examples


dev_skewlnorm(exp(-2:2))
dev_skewlnorm(exp(-2:2), 0, 1, 5)
dev_skewlnorm(exp(-2:2), 0, 1, 5, res = TRUE)


extras documentation built on July 16, 2026, 1:07 a.m.