| dev_skewlnorm | R Documentation |
Skew-Lognormal Deviances
dev_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0, res = FALSE)
x |
A numeric vector of values. |
meanlog |
A numeric vector of the means on the log scale. |
sdlog |
A non-negative numeric vector of the standard deviations on the log scale. |
shape |
A numeric vector of shape. |
res |
A flag specifying whether to return the deviance residual as opposed to the deviance. |
An numeric vector of the corresponding deviances or deviance residuals.
Other dev_dist:
dev_bern(),
dev_beta_binom(),
dev_binom(),
dev_gamma(),
dev_gamma_pois(),
dev_lnorm(),
dev_neg_binom(),
dev_norm(),
dev_pois(),
dev_pois_zi(),
dev_skewnorm(),
dev_student()
dev_skewlnorm(exp(-2:2))
dev_skewlnorm(exp(-2:2), 0, 1, 5)
dev_skewlnorm(exp(-2:2), 0, 1, 5, res = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.