Skew-Lognormal Log-Likelihood
Arguments
- x
A numeric vector of values.
- meanlog
A numeric vector of the means on the log scale.
- sdlog
A non-negative numeric vector of the standard deviations on the log scale.
- shape
A numeric vector of shape.
- tlower
A numeric vector of the lower truncation point.
- tupper
A numeric vector of the upper truncation point.
See also
Other log_lik_dist:
log_lik_bern(),
log_lik_beta(),
log_lik_beta_binom(),
log_lik_binom(),
log_lik_exp(),
log_lik_gamma(),
log_lik_gamma_pois(),
log_lik_gamma_pois_zi(),
log_lik_lnorm(),
log_lik_neg_binom(),
log_lik_norm(),
log_lik_pois(),
log_lik_pois_zi(),
log_lik_skewnorm(),
log_lik_student(),
log_lik_unif()