Skip to contents

Skew-Lognormal Log-Likelihood

Usage

log_lik_skewlnorm(
  x,
  locationlog = 0,
  scalelog = 1,
  shapelog = 0,
  tlower = 0,
  tupper = Inf,
  ...,
  meanlog,
  sdlog,
  shape
)

Arguments

x

A numeric vector of values.

locationlog

A numeric vector of location parameters of log(x).

scalelog

A non-negative numeric vector of scale parameters of log(x).

shapelog

A numeric vector of shape parameters of log(x). Negative values result in leftward skew, while positive values result in rightward skew.

tlower

A numeric vector of the lower truncation point.

tupper

A numeric vector of the upper truncation point.

...

Unused.

meanlog

[Deprecated] A numeric vector of location parameters of log(x). Described as "a numeric vector of the means on the log scale" prior to v. 0.10.1. Will be removed in a future version.

sdlog

[Deprecated] A non-negative numeric vector of scale parameters of log(x). Described as "a non-negative numeric vector of the standard deviations on the log scale" prior to v. 0.10.1. Will be removed in a future version.

shape

[Deprecated] A numeric vector of shape parameters of log(x). Will be removed in a future version.

Value

An numeric vector of the corresponding log-likelihoods.

Examples

log_lik_skewlnorm(1:5)
#> [1] -0.9189385 -1.8523122 -2.6210253 -3.2661389 -3.8235216
log_lik_skewlnorm(1:5, shapelog = -2)
#> [1]  -0.9189385  -3.6501479  -6.1964185  -8.4580739 -10.4790080
log_lik_skewlnorm(1:5, shapelog = 2)
#> [1] -0.9189385 -1.2456259 -1.9419793 -2.5757762 -3.1310181