Skew-Lognormal Log-Likelihood
Usage
log_lik_skewlnorm(
x,
locationlog = 0,
scalelog = 1,
shapelog = 0,
tlower = 0,
tupper = Inf,
...,
meanlog,
sdlog,
shape
)Arguments
- x
A numeric vector of values.
- locationlog
A numeric vector of location parameters of
log(x).- scalelog
A non-negative numeric vector of scale parameters of
log(x).- shapelog
A numeric vector of shape parameters of
log(x). Negative values result in leftward skew, while positive values result in rightward skew.- tlower
A numeric vector of the lower truncation point.
- tupper
A numeric vector of the upper truncation point.
- ...
Unused.
- meanlog
A numeric vector of location parameters of
log(x). Described as "a numeric vector of the means on the log scale" prior to v. 0.10.1. Will be removed in a future version.- sdlog
A non-negative numeric vector of scale parameters of
log(x). Described as "a non-negative numeric vector of the standard deviations on the log scale" prior to v. 0.10.1. Will be removed in a future version.- shape
A numeric vector of shape parameters of
log(x). Will be removed in a future version.
See also
Other log_lik_dist:
log_lik_bern(),
log_lik_beta(),
log_lik_beta_binom(),
log_lik_binom(),
log_lik_exp(),
log_lik_gamma(),
log_lik_gamma_pois(),
log_lik_gamma_pois_zi(),
log_lik_lnorm(),
log_lik_multinom(),
log_lik_neg_binom(),
log_lik_norm(),
log_lik_pois(),
log_lik_pois_zi(),
log_lik_skewnorm(),
log_lik_student(),
log_lik_unif()