Learn R Programming

extras (version 0.10.0)

prob_lnorm: Log-Normal Cumulative Distribution Function

Description

Log-Normal Cumulative Distribution Function

Usage

prob_lnorm(x, meanlog = 0, sdlog = 1)

Value

An numeric vector of the corresponding probabilities.

Arguments

x

A numeric vector of quantiles.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

See Also

Other prob_dist: prob_bern(), prob_beta(), prob_beta_binom(), prob_binom(), prob_exp(), prob_gamma(), prob_gamma_pois(), prob_gamma_pois_zi(), prob_neg_binom(), prob_norm(), prob_pois(), prob_pois_zi(), prob_skewlnorm(), prob_skewnorm(), prob_student(), prob_unif()

Examples

Run this code
prob_lnorm(10, 0, 2)

Run the code above in your browser using DataLab