Learn R Programming

extras (version 0.10.0)

prob_skewlnorm: Skew-Lognormal Cumulative Distribution Function

Description

Skew-Lognormal Cumulative Distribution Function

Usage

prob_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0)

Value

An numeric vector of the corresponding probabilities.

Arguments

x

A numeric vector of quantiles.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

See Also

Other prob_dist: prob_bern(), prob_beta(), prob_beta_binom(), prob_binom(), prob_exp(), prob_gamma(), prob_gamma_pois(), prob_gamma_pois_zi(), prob_lnorm(), prob_neg_binom(), prob_norm(), prob_pois(), prob_pois_zi(), prob_skewnorm(), prob_student(), prob_unif()

Examples

Run this code
if (FALSE) { # rlang::is_installed("sn")
prob_skewlnorm(1:5)
prob_skewlnorm(1:5, shape = -2)
prob_skewlnorm(1:5, shape = 2)
}

Run the code above in your browser using DataLab