powered by
Skew-Lognormal Cumulative Distribution Function
prob_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0)
An numeric vector of the corresponding probabilities.
A numeric vector of quantiles.
A numeric vector of the means on the log scale.
A non-negative numeric vector of the standard deviations on the log scale.
A numeric vector of shape.
Other prob_dist: prob_bern(), prob_beta(), prob_beta_binom(), prob_binom(), prob_exp(), prob_gamma(), prob_gamma_pois(), prob_gamma_pois_zi(), prob_lnorm(), prob_neg_binom(), prob_norm(), prob_pois(), prob_pois_zi(), prob_skewnorm(), prob_student(), prob_unif()
prob_bern()
prob_beta()
prob_beta_binom()
prob_binom()
prob_exp()
prob_gamma()
prob_gamma_pois()
prob_gamma_pois_zi()
prob_lnorm()
prob_neg_binom()
prob_norm()
prob_pois()
prob_pois_zi()
prob_skewnorm()
prob_student()
prob_unif()
if (FALSE) { # rlang::is_installed("sn") prob_skewlnorm(1:5) prob_skewlnorm(1:5, shape = -2) prob_skewlnorm(1:5, shape = 2) }
Run the code above in your browser using DataLab