Skip to contents

Skew-Lognormal Quantile Function

Usage

quant_skewlnorm(
  x,
  locationlog = 0,
  scalelog = 1,
  shapelog = 0,
  ...,
  meanlog,
  sdlog,
  shape
)

Arguments

x

A numeric vector of probabilities.

locationlog

A numeric vector of location parameters of log(x).

scalelog

A non-negative numeric vector of scale parameters of log(x).

shapelog

A numeric vector of shape parameters of log(x). Negative values result in leftward skew, while positive values result in rightward skew.

...

Unused.

meanlog

[Deprecated] A numeric vector of location parameters of log(x). Described as "a numeric vector of the means on the log scale" prior to v. 0.10.1. Will be removed in a future version.

sdlog

[Deprecated] A non-negative numeric vector of scale parameters of log(x). Described as "a non-negative numeric vector of the standard deviations on the log scale" prior to v. 0.10.1. Will be removed in a future version.

shape

[Deprecated] A numeric vector of shape parameters of log(x). Will be removed in a future version.

Value

An numeric vector of the corresponding quantiles.

Examples

quant_skewlnorm(c(0.1, 0.4, 0.6))
#> [1] 0.2776062 0.7761984 1.2883304
quant_skewlnorm(c(0.1, 0.4, 0.6), shapelog = -2)
#> [1] 0.1930513 0.4346470 0.6150948
quant_skewlnorm(c(0.1, 0.4, 0.6), shapelog = 2)
#> [1] 0.8747552 1.6257658 2.3007178