powered by
Skew-Lognormal Quantile Function
quant_skewlnorm(x, meanlog = 0, sdlog = 1, shape = 0)
An numeric vector of the corresponding quantiles.
A numeric vector of probabilities.
A numeric vector of the means on the log scale.
A non-negative numeric vector of the standard deviations on the log scale.
A numeric vector of shape.
Other quant_dist: quant_bern(), quant_beta(), quant_binom(), quant_exp(), quant_gamma(), quant_gamma_pois(), quant_gamma_pois_zi(), quant_lnorm(), quant_neg_binom(), quant_norm(), quant_pois(), quant_pois_zi(), quant_skewnorm(), quant_student(), quant_unif()
quant_bern()
quant_beta()
quant_binom()
quant_exp()
quant_gamma()
quant_gamma_pois()
quant_gamma_pois_zi()
quant_lnorm()
quant_neg_binom()
quant_norm()
quant_pois()
quant_pois_zi()
quant_skewnorm()
quant_student()
quant_unif()
if (FALSE) { # rlang::is_installed("sn") quant_skewlnorm(c(0.1, 0.4, 0.6)) quant_skewlnorm(c(0.1, 0.4, 0.6), shape = -2) quant_skewlnorm(c(0.1, 0.4, 0.6), shape = 2) }
Run the code above in your browser using DataLab