Log-Normal Random Samples
Usage
ran_lnorm(n = 1, meanlog = 0, sdlog = 1)
Arguments
- n
A non-negative whole number of the number of random samples to
generate.
- meanlog
A numeric vector of the means on the log scale.
- sdlog
A non-negative numeric vector of the standard deviations on the
log scale.
Value
A numeric vector of the random samples.
See also
Other ran_dist:
ran_bern(),
ran_beta_binom(),
ran_binom(),
ran_gamma(),
ran_gamma_pois(),
ran_gamma_pois_zi(),
ran_neg_binom(),
ran_norm(),
ran_pois(),
ran_pois_zi(),
ran_skewnorm(),
ran_student()
Examples
ran_lnorm(10)
#> [1] 6.1699764 0.3420323 1.0004303 3.6608010 2.0727888 0.1973487 0.1490575
#> [8] 1.4885793 0.1395189 0.5937731