powered by
Skew-Lognormal Random Samples
ran_skewlnorm(n = 1, meanlog = 0, sdlog = 1, shape = 0)
A numeric vector of the random samples.
A non-negative whole number of the number of random samples to generate.
A numeric vector of the means on the log scale.
A non-negative numeric vector of the standard deviations on the log scale.
A numeric vector of shape.
Other ran_dist: ran_bern(), ran_beta_binom(), ran_binom(), ran_gamma(), ran_gamma_pois(), ran_gamma_pois_zi(), ran_lnorm(), ran_neg_binom(), ran_norm(), ran_pois(), ran_pois_zi(), ran_skewnorm(), ran_student()
ran_bern()
ran_beta_binom()
ran_binom()
ran_gamma()
ran_gamma_pois()
ran_gamma_pois_zi()
ran_lnorm()
ran_neg_binom()
ran_norm()
ran_pois()
ran_pois_zi()
ran_skewnorm()
ran_student()
if (FALSE) { # rlang::is_installed("sn") ran_skewlnorm(10, shape = -1) ran_skewlnorm(10, shape = 0) ran_skewlnorm(10, shape = 1) }
Run the code above in your browser using DataLab