Skip to contents

Student's t Random Samples

Usage

ran_student(n = 1, mean = 0, sd = 1, theta = 0)

Arguments

n

A non-negative whole number of the number of random samples to generate.

mean

A numeric vector of the means.

sd

A non-negative numeric vector of the standard deviations.

theta

A non-negative numeric vector of the dispersion for the mixture models (student, gamma-Poisson and beta-binomial).

Value

A numeric vector of the random samples.

Examples

ran_student(10, theta = 1 / 2)
#>  [1] -3.2152450 -0.2669560  0.3559364  1.4817638 -0.8914654 -0.7134549
#>  [7] -0.4054444 -1.3419471  0.8591883  0.2969724