Skew-Lognormal Residuals
Usage
res_skewlnorm(
x,
locationlog = 0,
scalelog = 1,
shapelog = 0,
type = "dev",
simulate = FALSE,
...,
meanlog,
sdlog,
shape
)Arguments
- x
A numeric vector of values.
- locationlog
A numeric vector of location parameters of
log(x).- scalelog
A non-negative numeric vector of scale parameters of
log(x).- shapelog
A numeric vector of shape parameters of
log(x). Negative values result in leftward skew, while positive values result in rightward skew.- type
A string of the residual type. 'raw' for raw residuals 'dev' for deviance residuals and 'data' for the data.
- simulate
A flag specifying whether to simulate residuals.
- ...
Unused.
- meanlog
A numeric vector of location parameters of
log(x). Described as "a numeric vector of the means on the log scale" prior to v. 0.10.1. Will be removed in a future version.- sdlog
A non-negative numeric vector of scale parameters of
log(x). Described as "a non-negative numeric vector of the standard deviations on the log scale" prior to v. 0.10.1. Will be removed in a future version.- shape
A numeric vector of shape parameters of
log(x). Will be removed in a future version.
Examples
res_skewlnorm(exp(-2:2))
#> [1] -2 -1 0 1 2