res_skewlnorm: Skew-Lognormal Residuals

View source: R/res.R

res_skewlnormR Documentation

Skew-Lognormal Residuals

Description

Skew-Lognormal Residuals

Usage

res_skewlnorm(
  x,
  meanlog = 0,
  sdlog = 1,
  shape = 0,
  type = "dev",
  simulate = FALSE
)

Arguments

x

A numeric vector of values.

meanlog

A numeric vector of the means on the log scale.

sdlog

A non-negative numeric vector of the standard deviations on the log scale.

shape

A numeric vector of shape.

type

A string of the residual type. 'raw' for raw residuals 'dev' for deviance residuals and 'data' for the data.

simulate

A flag specifying whether to simulate residuals.

Value

An numeric vector of the corresponding residuals.

See Also

Other res_dist: res_bern(), res_beta_binom(), res_binom(), res_gamma(), res_gamma_pois(), res_gamma_pois_zi(), res_lnorm(), res_neg_binom(), res_norm(), res_pois(), res_pois_zi(), res_skewnorm(), res_student()

Examples


res_skewlnorm(exp(-2:2))


extras documentation built on July 16, 2026, 1:07 a.m.