| res_skewlnorm | R Documentation |
Skew-Lognormal Residuals
res_skewlnorm(
x,
meanlog = 0,
sdlog = 1,
shape = 0,
type = "dev",
simulate = FALSE
)
x |
A numeric vector of values. |
meanlog |
A numeric vector of the means on the log scale. |
sdlog |
A non-negative numeric vector of the standard deviations on the log scale. |
shape |
A numeric vector of shape. |
type |
A string of the residual type. 'raw' for raw residuals 'dev' for deviance residuals and 'data' for the data. |
simulate |
A flag specifying whether to simulate residuals. |
An numeric vector of the corresponding residuals.
Other res_dist:
res_bern(),
res_beta_binom(),
res_binom(),
res_gamma(),
res_gamma_pois(),
res_gamma_pois_zi(),
res_lnorm(),
res_neg_binom(),
res_norm(),
res_pois(),
res_pois_zi(),
res_skewnorm(),
res_student()
res_skewlnorm(exp(-2:2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.