| sens_skewlnorm | R Documentation |
Expands (sd_mult > 1) or reduces (sd_mult < 1) the standard deviation
of the Skew-Lognormal distribution while preserving its mean and shape.
The adjustment is made on the natural scale (i.e. for x, not for
log(x)), mirroring sens_lnorm(), to which it reduces when shape = 0.
sens_skewlnorm(meanlog, sdlog, shape, sd_mult = 2)
meanlog |
A numeric vector of the means on the log scale. |
sdlog |
A non-negative numeric vector of the standard deviations on the log scale. |
shape |
A non-negative numeric vector of shape. |
sd_mult |
A non-negative multiplier on the standard deviation of the distribution. |
A named list of the adjusted distribution's parameters.
Other sens_dist:
sens_beta(),
sens_exp(),
sens_gamma(),
sens_gamma_pois(),
sens_gamma_pois_zi(),
sens_lnorm(),
sens_neg_binom(),
sens_norm(),
sens_pois(),
sens_skewnorm(),
sens_student()
sens_skewlnorm(0, 1, 2, 2)
sens_skewlnorm(0, 1, 2, 0.8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.