Adjust Skew Normal Distribution Parameters for Sensitivity Analyses
Source:R/sens.R
sens_skewnorm.RdExpands (scale_mult > 1) or reduces (scale_mult < 1) the scale parameter
of the Skew Normal distribution without changing the mean.
Arguments
- location
A numeric vector of the location parameter.
- scale
A non-negative numeric vector of the scale parameter.
- shape
A numeric vector of shape. Negative values result in leftward skew, while positive values result in rightward skew.
- scale_mult
A non-negative multiplier on the scale of the distribution.
- ...
Unused.
- mean
A numeric vector of the location parameter. Described as "a numeric vector of the means" prior to to v. 0.10.1. Will be removed in a future version.
- sd
A non-negative numeric vector of the scale parameter. Described as "a non-negative numeric vector of the standard deviations" prior to v. 0.10.1. Will be removed in a future version.
- sd_mult