| dskewlnorm | R Documentation |
The skew-lognormal distribution of a value x whose natural logarithm
follows a Skew-Normal distribution with location meanlog,
scale sdlog and shape.
It reduces to the Log-Normal distribution when shape = 0.
dskewlnorm(x, meanlog = 0, sdlog = 1, shape = 0, log = FALSE)
pskewlnorm(q, meanlog = 0, sdlog = 1, shape = 0)
qskewlnorm(p, meanlog = 0, sdlog = 1, shape = 0)
rskewlnorm(n = 1, meanlog = 0, sdlog = 1, shape = 0)
x |
A numeric vector of values. |
meanlog |
A numeric vector of the means on the log scale. |
sdlog |
A non-negative numeric vector of the standard deviations on the log scale. |
shape |
A numeric vector of values. |
log |
A flag specifying whether to return the log-transformed value. |
q |
A vector of quantiles. |
p |
A numeric vector of probabilities. |
n |
A non-negative whole number of the number of random samples to generate. |
dskewlnorm gives the density, pskewlnorm gives the distribution function, qskewlnorm gives the quantile function, and rskewlnorm generates random deviates.
pskewlnorm and qskewlnorm use the lower tail probability.
dskewlnorm(x = 1:5, meanlog = 0, sdlog = 1, shape = 0.1)
dskewlnorm(x = 1:5, meanlog = 0, sdlog = 1, shape = -1)
qskewlnorm(p = c(0.1, 0.4), meanlog = 0, sdlog = 1, shape = 0.1)
qskewlnorm(p = c(0.1, 0.4), meanlog = 0, sdlog = 1, shape = -1)
pskewlnorm(q = 1:5, meanlog = 0, sdlog = 1, shape = 0.1)
pskewlnorm(q = 1:5, meanlog = 0, sdlog = 1, shape = -1)
rskewlnorm(n = 3, meanlog = 0, sdlog = 1, shape = 0.1)
rskewlnorm(n = 3, meanlog = 0, sdlog = 1, shape = -1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.