powered by
Calculates Bayesian credible intervals (CI) using one of the available methods:
"HDI": highest density interval (see xtr_ci_hdi()),
"HDI"
xtr_ci_hdi()
"ETI": equal tailed intervals (see xtr_ci_eti()).
"ETI"
xtr_ci_eti()
xtr_ci(x, level = 0.95, ..., type = "HDI", na_rm = FALSE)
A data.frame of the lower and upper limits for the credible interval. Note that the interval is not guaranteed to be one-sided or two-sided.
lower
upper
A numeric vector of MCMC samples.
A number > 0 and <= 1 specifying the probability coverage of the interval.
Currently unused.
A string indicating which type of CI to return. Currently allows Highest Density Intervals ("HDI"; default) and Equal-Tailed Intervals ("ETI").
A flag indicating whether to remove missing values.
mcmcr::coef
xtr_ci(rnorm(1e4), type = "HDI")
Run the code above in your browser using DataLab