| xtr_ci_eti | R Documentation |
Calculates Bayesian credible intervals using the equal-tailed interval (ETI), i.e., the CI such that the left and right tails outside the CI have the same coverage.
xtr_ci_eti(x, level = 0.95, ..., na_rm = FALSE)
x |
A numeric vector of MCMC samples. |
level |
A number > 0 and <= 1 specifying the probability coverage of the interval. |
... |
Currently unused. |
na_rm |
A flag indicating whether to remove missing values. |
The interval is guaranteed to be two-sided, unlike [xtr_ci_hdi()].
Does not return integer outputs even if the input data are integers,
unlike xtr_ci_hdi().
The interval limits are always real (double) numeric values.
A data.frame of the lower and upper limits for the credible
interval.
xtr_ci() and xtr_ci_hdi()
xtr_ci_eti(rnorm(1e4))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.